# -*- coding: utf-8 -*-
import os


class CorpusReader(object):

    def __init__(self, path):
        import pickle
        with open(path) as f:
            iob_sents = pickle.load(f)
        train_num = int(len(iob_sents) * 0.9)
        self.__train_sents = iob_sents[:train_num]
        self.__test_sents = iob_sents[train_num:]

    def iob_sents(self, name):
        if name == 'train':
            return self.__train_sents
        elif name == 'test':
            return self.__test_sents
        else:
            return None


hiron2016 = CorpusReader(os.path.join(os.path.abspath('hironsan/corpus'), 'hiron_corpus.pickle'))


import os
from setuptools import setup, find_packages


long_description = 'Japanese IOB2 tagged corpus for named entity recognition.'
if os.path.exists('README.txt'):
    with open('README.txt') as f:
        long_description = f.read()


setup(
    name='hironsancorpus',
    version='0.0.5',
    description='Japanese IOB2 tagged corpus for named entity recognition.',
    long_description=long_description,
    url='https://github.com/Hironsan/hironsan_corpus',
    download_url='',
    author='Hironsan',
    author_email='light.tree.1.13@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
    keywords=['corpus', 'IOB', 'named entity recognition', 'japanese corpus'],
    packages=find_packages(exclude=['tests*']),
)